import { fileURLToPath } from "url";
import path from "path";
var getFilename = () => fileURLToPath(import.meta.url);
var getDirname = () => path.dirname(getFilename());
var __dirname = /* @__PURE__ */ getDirname();
var __filename = /* @__PURE__ */ getFilename();
import { join } from "node:path";
import { defineConfig, loadConfig, mergeRsbuildConfig } from "@rsbuild/core";
import { pluginReact } from "@rsbuild/plugin-react";
import { pluginTypeCheck } from "@rsbuild/plugin-type-check";
import { pluginSvgr } from "@rsbuild/plugin-svgr";
import { pluginStylus } from "@rsbuild/plugin-stylus";
import { pluginBabel } from "@rsbuild/plugin-babel";
import { getEnv } from "../../common/getEnv.mjs";
import { require as require2 } from "../../common/utils/index.mjs";
const getRsbuildConfig = async (devConfig, paths) => {
  const env = getEnv(paths.publicUrlOrPath.slice(0, -1));
  const defaultConfig = defineConfig({
    plugins: [
      pluginReact(),
      pluginTypeCheck(),
      pluginSvgr(),
      pluginStylus(),
      pluginBabel({
        babelLoaderOptions: (config, { addPlugins }) => {
          addPlugins([require2.resolve("babel-plugin-jsx-css-modules")]);
        }
      })
    ],
    output: {
      polyfill: "entry",
      legalComments: "none",
      filename: process.env.NODE_ENV === "production" ? {
        js: "[name].[contenthash:16].js",
        css: "[name].[contenthash:16].css",
        svg: "[name].[contenthash:16].svg",
        font: "[name].[contenthash:16][ext]",
        image: "[name].[contenthash:16][ext]",
        media: "[name].[contenthash:16][ext]"
      } : {
        js: "[name].js",
        css: "[name].css",
        svg: "[name].[contenthash:16].svg",
        font: "[name].[contenthash:16][ext]",
        image: "[name].[contenthash:16][ext]",
        media: "[name].[contenthash:16][ext]"
      }
    },
    html: {
      template: paths.appHtml
    },
    tools: {
      bundlerChain(chain, utils) {
        chain.module.rule("svg").oneOf("sprite").test(/./).include.add(paths.svgSpritePath).end().before("svg-asset-url").use("compat-svg-sprite-loader").loader(join(__dirname, "../loader/compat-svg-sprite-loader.mjs")).options({ symbolId: "icon-[name]" }).end().use("svgo").loader(require2.resolve("svgo-loader"));
      }
    },
    source: {
      define: env.stringified
    },
    performance: { prefetch: true }
  });
  const { content: userConfig } = await loadConfig({
    cwd: process.cwd(),
    path: join(process.cwd(), "mango.config.mjs")
  });
  return mergeRsbuildConfig(defaultConfig, devConfig, userConfig);
};
export {
  getRsbuildConfig
};
